pub fn parse_text_completion(
completion: LLMCompletionResponse,
) -> ChatbotResult<String>Expand description
Collects all the completion choices to a string. Assumes the completion has only text message content, no tool calls or responses.
pub fn parse_text_completion(
completion: LLMCompletionResponse,
) -> ChatbotResult<String>Collects all the completion choices to a string. Assumes the completion has only text message content, no tool calls or responses.